@@ -7,7 +7,7 @@ import sys
 import typing
 from typing import Dict, Literal, Tuple, Type
 
-from sqlalchemy.types import BLOB, FLOAT, INTEGER, TEXT
+from sqlalchemy.types import BLOB, FLOAT, INTEGER, TEXT, VARCHAR
 
 if not hasattr(sys, "frozen"):
     KIARA_PLUGIN_TABULAR_BASE_FOLDER = os.path.dirname(__file__)
@@ -40,6 +40,7 @@ SQLALCHEMY_SQLITE_TYPE_MAP: Dict[Type, SqliteDataType] = {
     FLOAT: "REAL",
     TEXT: "TEXT",
     BLOB: "BLOB",
+    VARCHAR: "TEXT",
 }
 
 RESERVED_SQL_KEYWORDS = [
